@@ -475,7 +475,10 @@ class ParallelMaster(GenericMaster):
         db_dict["timestop"] = datetime.now()
         db_dict["totalcputime"] = (db_dict["timestop"] - start_time).seconds
         self.project.db.item_update(db_dict, job_id)
-        self.status.finished = True
+        if not self.convergence_check():
+            self.status.not_converged = True
+        else:
+            self.status.finished = True
         self._hdf5["status"] = self.status.string
         self._logger.info(
             "{}, status: {}, parallel master".format(self.job_info_str, self.status)
@@ -483,6 +486,19 @@ class ParallelMaster(GenericMaster):
         self.update_master()
         # self.send_to_database()
 
+    def convergence_check(self) -> bool:
+        """
+        Check if and all child jobs of the calculation are converged. May need be extended in the base classes depending
+        on the specific application
+
+        Returns:
+             (bool): If the calculation is converged
+        """
+        for job in self.iter_jobs(convert_to_object=False):
+            if job.status not in ["finished", "warning"]:
+                return False
+        return True
+
     def _validate_cores(self, job, cores_for_session):
         """
         Check if enough cores are available to start the next child job.
