@@ -513,13 +513,14 @@ class PyironTable(HasGroups):
 
 
 class TableJob(GenericJob):
+    _system_function_lst = [get_job_id]
+
     def __init__(self, project, job_name):
         super(TableJob, self).__init__(project, job_name)
         self.__version__ = "0.1"
         self.__hdf_version__ = "0.3.0"
         self.__name__ = "TableJob"
         self._analysis_project = None
-        self._system_function_lst = [get_job_id]
         self._pyiron_table = PyironTable(
             project=None,
             system_function_lst=self._system_function_lst,
